pub struct DCMolecularField {
base_field: DCField,
atomic_fields: Vec<DCAtomicField>,
}Expand description
An abstract field which provides an interface to access multiple atomic fields under one field and one identifier.
Fields
base_field: DCFieldatomic_fields: Vec<DCAtomicField>Implementations
Sourceimpl DCMolecularField
impl DCMolecularField
pub fn get_num_atomics(&self) -> usize
pub fn get_atomic_field(&self, index: usize) -> Option<&DCAtomicField>